package messagelog

import (
	"sync"
)

type Log struct {
	log     map[string][]Message
	logLock sync.RWMutex
}

func (ml *Log) AddTopic(topic string, capacity int) {
	ml.logLock.Lock()
	ml.log[topic] = make([]Message, 0, capacity)
	ml.logLock.Unlock()
}

func (ml *Log) Push(topic string, message Message) error {
	if err := message.validate(); err != nil {
		return err
	}
	ml.logLock.Lock()
	defer ml.logLock.Unlock()
	log, ok := ml.log[topic]
	if !ok {
		return &ErrTopicNotFound{topic: topic}
	}
	message.Index = len(log)
	ml.log[topic] = append(log, message)
	return nil
}

func (ml *Log) List(topic string, offset int) ([]Message, error) {
	ml.logLock.RLock()
	defer ml.logLock.RUnlock()
	log, ok := ml.log[topic]
	if !ok {
		return nil, &ErrTopicNotFound{topic: topic}
	}
	if offset >= len(log) {
		return []Message{}, nil
	}
	return log[offset:], nil
}

func New() *Log {
	return &Log{
		log: map[string][]Message{},
	}
}
